#include "intervaldialog.h"
#include "ui_intervaldialog.h"

intervalDialog::intervalDialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::intervalDialog)
{
    ui->setupUi(this);
    this->show();
    m_query = new QSqlQuery(m_db);
}

intervalDialog::~intervalDialog()
{
    delete ui;
}

void intervalDialog::setInfoLabelText(QString string){
    ui->infoLabel->setText(string);
}

void intervalDialog::tableView()
{
    QSqlQueryModel* result_model = new QSqlQueryModel(this);
    m_query->exec("SELECT film_id AS Number, title, duration, year FROM films;");
    result_model->setQuery(*m_query);
    ui->tableView->setModel(result_model);
}

void intervalDialog::on_pushButton_clicked()
{
    qDebug()<<mode;
    if (ui->dateFrom->date() >= ui->dateTo->date()){
        ui->errorLabel->setText("Неверно заданы интервалы!");
    }
    else {
        if (mode == "") qDebug()<<"Не задан ключ!!!!";
        if (mode == "tickets")
            ticketsMode(ui->dateFrom->date(), ui->dateTo->date());

        if (mode == "hallIncome")
            hallIncomeMode(ui->dateFrom->date(), ui->dateTo->date());

        if (mode == "filmIncome")
            filmIncomeMode(ui->dateFrom->date(), ui->dateTo->date());
    }
}

void intervalDialog::ticketsMode(QDate from, QDate to){
    m_query->prepare("SELECT Films.title, Tickets.purchase_date, Tickets.customer, Halls.hall_id, Sessions.price   FROM Tickets JOIN Sessions ON Tickets.session_id = Sessions.session_id JOIN Films ON Sessions.film_id = Films.film_id JOIN Halls ON Sessions.hall_id = Halls.hall_id WHERE Tickets.purchase_date BETWEEN :from AND :to ORDER BY purchase_date;");
    m_query->bindValue(":from", from.toString("yyyy-MM-dd"));
    m_query->bindValue(":to", to.toString("yyyy-MM-dd"));

    if (!m_query->exec() && !m_query->next())
        qDebug() << "Error executing query: " << m_query->lastError().text();

    QSqlQueryModel* result_model = new QSqlQueryModel(this);
    result_model->setQuery(*m_query);
    ui->tableView->setModel(result_model);
}
void intervalDialog::hallIncomeMode(QDate from, QDate to){
    m_query->prepare("SELECT Halls.hall_id, SUM(Sessions.price) AS profit FROM Halls JOIN Sessions ON Halls.hall_id = Sessions.hall_id JOIN Tickets ON Sessions.session_id = Tickets.session_id WHERE Tickets.purchase_date BETWEEN :from AND :to GROUP BY Halls.hall_id;");
    m_query->bindValue(":from", from.toString("yyyy-MM-dd"));
    m_query->bindValue(":to", to.toString("yyyy-MM-dd"));

    if (!m_query->exec() && !m_query->next())
        qDebug() << "Error executing query: " << m_query->lastError().text();

    QSqlQueryModel* result_model = new QSqlQueryModel(this);
    result_model->setQuery(*m_query);
    ui->tableView->setModel(result_model);
}
void intervalDialog::filmIncomeMode(QDate from, QDate to){
    m_query->prepare("SELECT Films.title, SUM(Sessions.price) AS profit FROM Films LEFT JOIN Sessions ON Films.film_id = Sessions.film_id LEFT JOIN Tickets ON Sessions.session_id = Tickets.session_id WHERE Tickets.purchase_date BETWEEN :from AND :to GROUP BY Films.title;");
    m_query->bindValue(":from", from.toString("yyyy-MM-dd"));
    m_query->bindValue(":to", to.toString("yyyy-MM-dd"));
    qDebug()<<from.toString("yyyy-MM-dd")<<to.toString("yyyy-MM-dd");
    if (!m_query->exec() && !m_query->next())
        qDebug() << "Error executing query: " << m_query->lastError().text();

    QSqlQueryModel* result_model = new QSqlQueryModel(this);
    result_model->setQuery(*m_query);
    ui->tableView->setModel(result_model);
}
